
package de.web.databasesupport.tools.iotools;

import java.io.Reader;
import java.io.FileReader;
import java.io.BufferedReader;
import java.io.Writer;
import java.io.FileWriter;
import java.io.BufferedWriter;
import java.io.PrintWriter;
import java.io.IOException;
import java.io.FileNotFoundException;

import java.io.File;

/** Diese Klasse stellt Methoden zur Dateiverwaltung zur Verfgung. */
public class IOTools {

    /** Kopiert eine Datei.
      * Eine bereits bestehende Zieldatei wird berschrieben.
      * @param source Der Name der Quelldatei.
      * @param destination Der Name der Zieldatei.
      * @return true wenn Datei kopiert werden konnte.
      * @throw IOException Wenn Ein Schreib-Lesefehler aufgetreten ist.
      * @throw FileNotFoundException Wenn die Quelldatei nicht existiert oder die Quelle ein Verzeichnis ist.
      */
    public static void filecopy(String source, String destination) throws IOException, FileNotFoundException{
        Reader r;
        Writer w;
        int ic;             // zum Lesen eines Zeichens als int

        File src = new File(source);

        if (!src.exists() || src.isDirectory() ) throw new FileNotFoundException("Datei " + source + " nicht vorhanden");

        r = new BufferedReader(new FileReader(source));

        w = new PrintWriter(new BufferedWriter(new FileWriter(destination)));

        while ((ic = r.read()) != -1) // Zeichen lesen und prfen ob Dateiende
        {
          w.write(ic); // Zeichen schreiben
        }

        // schlieen der Streams mu auf jedenfall erfolgen! DATENVERLUST!!!
        r.close();
        w.close();
    }

    /** Kopiert eine Datei.
      * Eine bereits bestehende Zieldatei wird berschrieben.
      * @param source Der Name der Quelldatei.
      * @param destination Der Name der Zieldatei.
      * @param overwrite Gibt an ob eine bestehende Datei berschrieben werden darf (true).
      * @return true wenn Datei kopiert werden konnte.
      * @throw IOException Wenn Ein Schreib-Lesefehler aufgetreten ist.
      * @throw FileNotFoundException Wenn die Quelldatei nicht existiert oder die Quelle ein Verzeichnis ist.
      */
    public static boolean filecopy(String source, String destination, boolean overwrite) throws IOException, FileNotFoundException{
        File dest = new File(destination);

        if (dest.exists() && !overwrite) {
            return false;
        }
        else {
            filecopy(source, destination);
        }

        return true;
    }


}
