package de.web.databasesupport.tools.test;
import java.io.*;
import de.web.databasesupport.tools.iotools.*;
import java.sql.*;

/********************************************************************
  *
  *  program     : MakeHTMLLog.java
  *  author      : Niels-Peter de Witt
  *  version     : 2001-04-12(001)
  *  (c)         : Helge Janicke, Niels-Peter de Witt, Karsten Wolke
  *  email       : heljanic@agent.fho-emden.de
  *              : ndewitt@gmx.de
  *              : mail@karsten-wolke.de
  *  description : Generates HTML-Log-files
  *
  *******************************************************************
  * modifications: See at the end of the document.
  *******************************************************************
  * comments:
  *******************************************************************
  * license:
  * This software is provided AS IS, without a warranty of any
  * kind. ALL EXPRESS OR IMPLIED CONDITIONS, REPRESENTATION AND
  * WARRANTIES, INCLUDING ANY IMLIED WARRANTY OF MERCHANTABILITY,
  * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE
  * HEREBY EXCLUDED. WE SHALL NOT BE LIABLE FOR ANY DAMAGES
  * SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR
  * DISTRIBUTING THE SOFTWARE OR ITS DERIVATIVES. IN NO EVENT WE
  * WILL BE LIABLE FOR ANY LOST REVENUE, PROFIT OR DATA, OR FOR
  * DIRECT, INDIRECT, SPECIAL, CENSEQUENTIAL, INCIDENTIAL OR
  * PUNITIVE DAMAGES, HOWEVER CAUSED AND REGARDLESS OF THE THEORY
  * OF LIABILITY, ARISING OUT OF THE USE OF OR INABILITY TO USE
  * SOFTWARE, EVEN IF WE HAVE BEEN ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGES.
  * This software is not designed or intended for use in online
  * control of aircraft, air traffic, aircraft navigation or
  * aircraft communications; or in the design, construction,
  * operation or maintenance of any nuclear facility. Licensee
  * represents and warrants that it will not use or redistribute
  * the software for such purposes.
********************************************************************/

 /** Generates a HTML-Log-file
    */
public class MakeHTMLLog {

    public static java.util.Vector links = new java.util.Vector();


    public MakeHTMLLog() {

    }

 /** generates a complete HTML-file and  checks if file exists already.
    * @param classDescription The description of the used class.
    * @param tMethods All tested methods with there results.
    * @param dest Destination-file where to put the information from tMethods in.
    * @param overwrite Flag if overwriting an existing file is allowed (<tt>true</tt> is allowed, <tt>false</tt> otherwise).
    * @return Returns <tt>true</tt> if writing was successfull, <tt>false</tt> if file already exists and it is not allowed to overwrite it.
    * @throws IOException - if something went wrong with the writing, or creating of the destination-file.
    */
    public static boolean makeHTML(String classDescription, TestedMethod[] tMethods, File dest, boolean overwrite)
    throws IOException {

        if (tMethods.length > 0) {
            int filledCounter = 0;
            for (int i=0;  i<tMethods.length; i++) {
                if (!tMethods[i].isEmptyTestedMethod()) {
                    filledCounter = i;
                    break;
                }
            }

            String classname = tMethods[filledCounter].getClassname();
            String tester = tMethods[filledCounter].getTester();
            long datelong = tMethods[filledCounter].getDate();
            String date = MakeHTMLLog.getDate(datelong);
            String time = MakeHTMLLog.getTime(datelong);
            StringBuffer test = new StringBuffer();
            test.append(headerHTML( classname, classDescription, tester, date, time));
            String body = bodyHTML(tMethods);
            test.append(generateLinkList(links));
            test.append(body);
            test.append(footerHTML());
            return ASCIIFile.write(dest, test.toString(), overwrite);
        }
        else return false;
    }

 /** generates a Date-String (YYYY-MM-DD) from a date given in milliseconds since 1970.
    * @param date The milliseconds since 1970.
    * @return Returns the date as String.
    */
    public static String getDate(long date) {
        Date datum = new Date(date);
        return datum.toString();
    }

 /** generates a Time-String (HH:MM:SS) from a date given in milliseconds since 1970.
    * @param date The milliseconds since 1970.
    * @return Returns the time as String.
    */
    public static String getTime(long date) {
        Time time = new Time(date);
        return time.toString();
    }

 /** generates a HTML-header including classname, tester, date, time and a class-description.
    * @param classname The name of the tested class.
    * @param classDescription The Description about the tested class.
    * @param tester The name of the tester.
    * @param date The date of the test.
    * @param time The beginning of the test.
    * @return The HTML-Code as a String.
    */
    public static String headerHTML(String classname, String classDescription, String tester, String date, String time) {
        StringBuffer rv = new StringBuffer();
        rv.append("<html>\n");
        rv.append("<head>\n");
        rv.append("<title>Test - protocol of "+classname+"</title>\n");
        rv.append("<meta http-equiv=\"Content-Type\" content=\"text/html; charset=iso-8859-1\">\n");
        rv.append("</head>\n");
        rv.append("<body bgcolor=\"#FFFFCC\" text=\"#000000\">\n");
        rv.append("<hr noshade width=\"100%\" size=\"10\">\n");
        rv.append("<h1 align=\"center\">Test-protocol of class : &quot;"+classname);
        rv.append("&quot;</h1>\n");
        rv.append("<h2 align=\"center\">Tested by "+tester+"</h2>\n");
        rv.append("<h2 align=\"center\">Date "+date+"&nbsp;&nbsp;&nbsp;&nbsp;Time ");
        rv.append(time+"</h2>\n");
        rv.append("<hr noshade width=\"100%\" size=\"10\">\n");
        rv.append("<h2 align=\"center\">Description of class:</h2>\n");
        rv.append("<h2 align=\"center\">"+classDescription+"</h2>\n");
        rv.append("<hr noshade width=\"100%\" size=\"10\">\n");
        return rv.toString();
    }

 /** generates a standard HTML-header
    * @param title The title of the HTML-document.
    * @return The HTML-Code as String
    */
    public static String headerHTML(String title) {
        StringBuffer rv = new StringBuffer();
        rv.append("<html>\n");
        rv.append("<head>\n");
        rv.append("<title>"+title+"</title>\n");
        rv.append("<meta http-equiv=\"Content-Type\" content=\"text/html; charset=iso-8859-1\">\n");
        rv.append("</head>\n");
        rv.append("<body>\n");
        return rv.toString();
    }

 /** generates a HTML-footer.
    * @return The HTML-Code of the footer as a String.
    */
    public static String footerHTML() {
        return "</body>\n</html>\n";
    }

 /** generates a HTML-body using de.gmx.ndewitt.tools.test.TestedMenthod - objects.
    * @param tMethods The TestedMethod-Objects to get information about the test.
    * @return The HTML-Body-code as a String including all Information from the tMethods-Objects.
    */
    public static String bodyHTML(TestedMethod[] tMethods) {
        StringBuffer rv = new StringBuffer();
        for (int i=0;  i<tMethods.length; i++) {
            // look for an empty TestedMethod - object.
            // if there is one, generate linklist.
            if (tMethods[i].isEmptyTestedMethod()) {
                    rv.append(makeAnchorTarget(tMethods[i].getMethodName()));
                    links.add(generateLink(tMethods[i].getMethodName()));
                    if (i>0) rv.append(makeToTop());
           } else {
                rv.append("<hr noshade width=\"100%\" size=\"5\">\n");
                rv.append("Name of method: <b>"+tMethods[i].getMethodName()+"</b><br>\n");
                rv.append("Date: " + getDate(tMethods[i].getDate()) + "&nbsp;&nbsp;&nbsp;&nbsp;Time: "+ getTime(tMethods[i].getDate()) +"<br>\n");
                rv.append("Testerclass: "+tMethods[i].getTestClass()+"\n");
                rv.append("<hr noshade width=\"50%\" size=\"2\" align=\"left\">\n");
                rv.append("<b>Description of method usages:</b><br>\n");
                rv.append(tMethods[i].getUsedMethodDescription()+"\n");
                rv.append("<hr noshade width=\"50%\" size=\"2\" align=\"left\">\n");
                rv.append("<font color=\"#006633\"><b>Parameter: </b></font> \n");
                rv.append("<ul>\n");
                for (int k=0; k<tMethods[i].getParameter().length; k++) {
                  rv.append("<li>" + tMethods[i].getParameter()[k] + "</li>\n");
                }
                rv.append("</ul>\n");
                rv.append("<hr noshade width=\"50%\" size=\"2\" align=\"left\">\n");
                rv.append("<b>Method-Log:</b><br>\n");
                rv.append(tMethods[i].getMethodLog() + "\n");
               if (tMethods[i].isExistsResult()) {
                  rv.append("<hr noshade width=\"50%\" size=\"2\" align=\"left\">\n");
                  rv.append("<b>Result:</b>\n");
                  rv.append("<blockquote>\n");
                  for (int k=0; k < tMethods[i].getResultlog().size(); k++) {
                    rv.append(tMethods[i].getResultlog().get(k).toString()+"<br>\n");
                  }
                  rv.append("</blockquote><br>\n");
                }
                if ( !tMethods[i].isWithoutException()) {
                  rv.append("<hr noshade width=\"50%\" size=\"2\" align=\"left\">\n");
                  rv.append("<font color=\"#FF0000\"><b>Method has thrown exception:</b><br></font>\n");
                  rv.append(tMethods[i].getExceptionlog() +"\n");
                }
                rv.append("<hr noshade width=\"100%\" size=\"5\" align=\"left\">\n");
            }
        }
        rv.append(makeToTop());
        return rv.toString();
    }

 /** generates a HTML-body using de.gmx.ndewitt.tools.test.TestedMenthod - objects.
    * @param tMethod The TestedMethod-Object to get information about the test.
    * @return The HTML-Body-code as a String including all Information from the tMethod-Object.
    */
    public static String bodyHTML(TestedMethod tMethod) {
        TestedMethod[] testM = new TestedMethod[1];
        return bodyHTML(testM);
    }


 /** generates a link-list from given HTML-Strings
    * @param links The HTML-Strings, containing the links.
    * @return The HTML-Code for the link-list.
    */
    public static String generateLinkList(java.util.Vector links) {
        if (links.size()>0) {
            StringBuffer rv = new StringBuffer();
            rv.append("<a name=\"linklist\"></a><h3>Tested methods:</h3> <br>\n");
            rv.append("<blockquote>\n");
            rv.append("<ul>\n");
            for (int i=0; i<links.size(); i++) {
              rv.append("<li>"+links.get(i).toString()+"</li>\n");
            }
            rv.append("</ul>\n");
            rv.append("</blockquote>\n");
            rv.append("<hr noshade width=\"100%\" size=\"10\">\n");
            return rv.toString();
        } else return "";
    }

 /** generates a links from the method-name
    * @param methodName The name of the method.
    * @return The HTML-Code containing the link to spezified method.
    */
    public static String generateLink(String methodName) {
        String rv = "";
        rv = "<a href=\"#"+methodName+"\">"+methodName+"</a>\n";
        return rv;
    }

 /** generates a anchor-point at the method-name
    * @param methodName The name of the method.
    * @return The HTML-Code containing the anchor for the spezified method.
    */
    public static String makeAnchorTarget(String methodName) {
        return "<a name=\""+ methodName + "\"></a>";
    }

 /** generates a link to the top (target is #linklist).
    * @return The HTML-Code containing the link to the top and a 100% horizontal ruler with a size of 10.
    */
    public static String makeToTop() {
        String rv = "";
        rv = "<center><a href=\"#linklist\">To Top</a></center><br>\n<hr noshade width=\"100%\" size=\"10\">\n";
        return rv;
    }

 /** generates from a ResultSet a Vector of Strings including a header, columnname and content.
    * @param resultset The ResultSet to generate a Vector of Strings from.
    * @return A Vector of String including a header, columnname and content.
    */
    public static java.util.Vector showResult(ResultSet resultset) {
        java.util.Vector resultvec = new java.util.Vector();
        try {
            if (resultset != null) {
                ResultSetMetaData meta = resultset.getMetaData();
                int ccount = meta.getColumnCount();
                resultvec.add("ResultSet contains "+ccount+" columns.");
                resultvec.add("");
                try {
                    while (resultset.next()) {
                        resultvec.add("...........................");
                        String cname ="";
                        for (int k=1; k<=ccount; k++) {
                            try {
                                cname = meta.getColumnName(k);
                                Object cvalue = resultset.getObject(k);
                                resultvec.add(k+". "+cname+" contains "+cvalue.toString());
                            } catch (NullPointerException exc) {
                                resultvec.add(k+". "+cname+" contains null");
                            }
                        }
                    }
                } catch(SQLException exc) {
                    resultvec.add("There was no row");
                }
            } else {
                resultvec.add("ResultSet was null.");
            }
        } catch (Exception ex) {
            resultvec.add("Error in showing ResultSet");
            resultvec.add("Exception:");
            resultvec.add(ex.toString());
        }
        return resultvec;
    }

 /** generates from a String-array a Vector of Strings including a header, columnname and content.
    * @param array The String-array to generate a Vector of Strings from.
    * @return A Vector of String including a header, columnname and content.
    */
    public static java.util.Vector showStringArray(String[] array) {
        java.util.Vector resultvec = new java.util.Vector();
        if (array==null) {
            resultvec.add("Array was null");
        } else {
            resultvec.add("Result of Array:");
            resultvec.add("");
            resultvec.add("Array contains "+array.length+" String-objects.");
            resultvec.add("");
            for (int i=0; i<array.length; i++) {
                resultvec.add(i+". "+array[i]);
            }
        }
        return resultvec;
    }

 /** Adds to a Vector a information header at the front.
    * @param vec The Vector of Strings to add a header to.
    * @return Adds to a Vector a information header at the front.
    */
    public static java.util.Vector showStringVector(java.util.Vector vec) {
        java.util.Vector resultvec = new java.util.Vector();
        if (vec==null) {
            resultvec.add("Vector was null");
        } else {
            resultvec.add("Result of Vector:");
            resultvec.add("");
            resultvec.add("Vector contains "+vec.size()+" String-objects.");
            resultvec.add("");
            for (int i=0; i<vec.size(); i++) {
                resultvec.add(i+". "+vec.get(i).toString());
            }
        }
        return resultvec;
    }
}