package de.web.databasesupport.tools.test;

/********************************************************************
  *
  *  program     : TestedMethod.java
  *  author      : Niels-Peter de Witt
  *  version     : 2001-04-12(001)
  *  (c)         : Helge Janicke, Niels-Peter de Witt, Karsten Wolke
  *  email       : heljanic@agent.fho-emden.de
  *              : ndewitt@gmx.de
  *              : mail@karsten-wolke.de
  *  description : Contains Information about a testrun on a method.
  *
  *******************************************************************
  * modifications: See at the end of the document.
  *******************************************************************
  * comments:
  *******************************************************************
  * license:
  * This software is provided AS IS, without a warranty of any
  * kind. ALL EXPRESS OR IMPLIED CONDITIONS, REPRESENTATION AND
  * WARRANTIES, INCLUDING ANY IMLIED WARRANTY OF MERCHANTABILITY,
  * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE
  * HEREBY EXCLUDED. WE SHALL NOT BE LIABLE FOR ANY DAMAGES
  * SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR
  * DISTRIBUTING THE SOFTWARE OR ITS DERIVATIVES. IN NO EVENT WE
  * WILL BE LIABLE FOR ANY LOST REVENUE, PROFIT OR DATA, OR FOR
  * DIRECT, INDIRECT, SPECIAL, CENSEQUENTIAL, INCIDENTIAL OR
  * PUNITIVE DAMAGES, HOWEVER CAUSED AND REGARDLESS OF THE THEORY
  * OF LIABILITY, ARISING OUT OF THE USE OF OR INABILITY TO USE
  * SOFTWARE, EVEN IF WE HAVE BEEN ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGES.
  * This software is not designed or intended for use in online
  * control of aircraft, air traffic, aircraft navigation or
  * aircraft communications; or in the design, construction,
  * operation or maintenance of any nuclear facility. Licensee
  * represents and warrants that it will not use or redistribute
  * the software for such purposes.
********************************************************************/

 /** Contains Information about a testrun on a method
    */
public class TestedMethod {

    private long  date;
    private String methodName;
    private String methodDescription;
    private String usedMethodDescription;
    private String methodLog;
    private String exceptionLog;
    private String classname;
    private String tester;
    private String[] parameter;
    private boolean existsResult;
    private boolean withoutException;
    private boolean emptyTestedMethod;
    private java.util.Vector resultLog;
    private String testClass;

 /** Constructs a new TestedMethod - object and sets the classname of the tested class,
    * the methodname of the tested method and signs it as a empty TestedMethod - object.
    * This constructor is only used for the linklist generator.
    * @param classname The name of the tested class.
    * @param methodName The name of the tested Method.
    */
    public TestedMethod(String classname, String methodName) {
        this.methodName = methodName;
        this.classname = classname;
        this.emptyTestedMethod = true;
    }


 /** Constructs a new TestedMethod - object and sets the classname of the tested class,
    *the methodname of the tested method, the general description of the method, who tests
    *this method the description how a tests will use this method and when the tests runs.
    * @param classname The name of the tested class.
    * @param methodName The name of the tested Method.
    * @param methodDescription The general description of the method.
    * @param tester The name of the tester.
    * @param usedMethodDescription The description how the tested method will be used.
    * @param date The time of the beginning of the test.
    * @param testClass The testerClass who generates the TestedMethod-object.
    */
    public TestedMethod(String classname, String methodName,  String methodDescription,
                                        String tester, String usedMethodDescription, long date, String testClass) {
        this.methodName = methodName;
        this.methodDescription = methodDescription;
        this.usedMethodDescription = usedMethodDescription;
        this.classname = classname;
        this.tester = tester;
        this.date = date;
        this.existsResult = false;
        this.withoutException = false;
        this.testClass = testClass;
    }

 /** Returns the classname of the tested class.
    * @return The classname of the tested class.
    */
    public String getClassname() {
        return classname;
    }

 /** Returns the classname of the tester class who generated the TestedMethod-object..
    * @return The classname of the tester class who generated the TestedMethod-object..
    */
    public String getTestClass() {
        return testClass;
    }

 /** Returns if the TestedMethod is signed as empty.
    * @return If the TestedMethod is signed as empty.
    */
    public boolean isEmptyTestedMethod() {
        return emptyTestedMethod;
    }

 /** Returns the general method description.
    * @return The general method description.
    */
    public String getMethodDescription() {
        return methodDescription;
    }

 /** Sets the used parameters of this TestedMethod-object.
    * @param parameter The parameters used for the test.
    */
    public void setParameter(String[] parameter) {
        this.parameter = parameter;
    }

 /** Returns the testername.
    * @return The testername.
    */
    public String getTester() {
        return tester;
    }

 /** Sets the log of the method.
    * @param methodLog The log of the method in the testrun.
    */
    public void setMethodLog(String methodLog) {
        this.methodLog = methodLog;
    }

 /** Sets the log of the thrown exceptions in the method.
    * @param exceptionLog The log of the thrown exceptions in the testrun.
    */
    public void setExceptionlog(String exceptionLog) {
        this.exceptionLog = exceptionLog;
    }

 /** Sets if there was a result generated by the tested method.
    * @param existsResult If a result was generetad by the tested method.
    */
    public void setExistsResult(boolean existsResult) {
        this.existsResult = existsResult;
    }

 /** Sets if there was no exception in the testrun of the method.
    * @param withoutException If there was no exception in the testrun of the method.
    */
    public void setWithoutException(boolean withoutException) {
        this.withoutException = withoutException;
    }

 /** Sets the log of the results produced in the method.
    * @param resultLog The log of the results produced in the method.
    */
    public void setResultlog(java.util.Vector resultLog) {
        this.resultLog = resultLog;
    }

 /** Returns the methodname.
    * @return The methodname.
    */
    public String getMethodName() {
        return methodName;
    }

 /** Returns the date of the start of the test.
    * @return The date of the start of the test.
    */
    public long getDate() {
        return date;
    }

 /** Returns the description how the method was used in the test.
    * @return The description how the method was used in the test.
    */
    public String getUsedMethodDescription() {
        return usedMethodDescription;
    }

 /** Returns the parameter of the test.
    * @return The parameter of the test.
    */
    public String[] getParameter() {
        return parameter;
    }

 /** Returns the log of what the method has done.
    * @return The log of what the method has done.
    */
    public String getMethodLog() {
        return methodLog;
    }

 /** Returns if a result exists.
    * @return If a result exists.
    */
    public boolean isExistsResult() {
        return existsResult;
    }

 /** Returns a Vector with Strings containing all results the method has made.
    * @return A Vector with Strings containing all results the method has made.
    */
    public java.util.Vector getResultlog() {
        return resultLog;
    }

 /** Returns if there was no exception.
    * @return If there was no exception.
    */
    public boolean isWithoutException() {
        return withoutException;
    }

 /** Returns the log of the throwns exception.
    * @return The log of the throwns exception.
    */
    public String getExceptionlog() {
        return exceptionLog;
    }
}